==> dotnet6_6.0.136.orig.tar.xz: src/roslyn-analyzers/src/Microsoft.CodeAnalysis.Analyzers/Core/AnalyzerReleases.Shipped.md <==
## Release 3.0.0

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1024 | MicrosoftCodeAnalysisCorrectness | Warning | CompareSymbolsCorrectlyAnalyzer
RS1025 | MicrosoftCodeAnalysisCorrectness | Warning | ConfigureGeneratedCodeAnalysisAnalyzer
RS1026 | MicrosoftCodeAnalysisCorrectness | Warning | EnableConcurrentExecutionAnalyzer
RS1027 | MicrosoftCodeAnalysisCorrectness | Warning | ClassIsNotDiagnosticAnalyzer
RS1028 | MicrosoftCodeAnalysisDocumentation | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1029 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1030 | MicrosoftCodeAnalysisCorrectness | Warning | DoNotUseCompilationGetSemanticModelAnalyzer
RS2000 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2001 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2002 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2003 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2004 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2005 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2006 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2007 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2008 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)

## Release 2.9.8

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1001 | MicrosoftCodeAnalysisCorrectness | Warning | DiagnosticAnalyzerAttributeAnalyzer
RS1002 | MicrosoftCodeAnalysisCorrectness | Warning | RegisterActionAnalyzer
RS1003 | MicrosoftCodeAnalysisCorrectness | Warning | RegisterActionAnalyzer
RS1004 | MicrosoftCodeAnalysisCorrectness | Warning | DiagnosticAnalyzerAttributeAnalyzer
RS1005 | MicrosoftCodeAnalysisCorrectness | Warning | ReportDiagnosticAnalyzer
RS1006 | MicrosoftCodeAnalysisCorrectness | Warning | RegisterActionAnalyzer
RS1007 | MicrosoftCodeAnalysisLocalization | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1008 | MicrosoftCodeAnalysisPerformance | Warning | DiagnosticAnalyzerFieldsAnalyzer
RS1009 | MicrosoftCodeAnalysisCompatibility | Error | InternalImplementationOnlyAnalyzer
RS1010 | Correctness | Warning | FixerWithFixAllAnalyzer
RS1011 | Correctness | Warning | FixerWithFixAllAnalyzer
RS1012 | MicrosoftCodeAnalysisPerformance | Warning | RegisterActionAnalyzer
RS1013 | MicrosoftCodeAnalysisPerformance | Warning | RegisterActionAnalyzer
RS1015 | MicrosoftCodeAnalysisDocumentation | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1016 | Correctness | Warning | FixerWithFixAllAnalyzer
RS1017 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1018 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1019 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1020 | MicrosoftCodeAnalysisDesign | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1021 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1022 | MicrosoftCodeAnalysisCorrectness | Warning | DiagnosticAnalyzerApiUsageAnalyzer
RS1023 | Library | Warning | UpgradeMSBuildWorkspaceAnalyzer

## Release 3.3.0

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1031 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1032 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1033 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer

==> dotnet8_8.0.122-8.0.22.orig.tar.xz: src/roslyn-analyzers/src/Microsoft.CodeAnalysis.Analyzers/Core/AnalyzerReleases.Shipped.md <==
## Release 2.9.8

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1001 | MicrosoftCodeAnalysisCorrectness | Warning | DiagnosticAnalyzerAttributeAnalyzer
RS1002 | MicrosoftCodeAnalysisCorrectness | Warning | RegisterActionAnalyzer
RS1003 | MicrosoftCodeAnalysisCorrectness | Warning | RegisterActionAnalyzer
RS1004 | MicrosoftCodeAnalysisCorrectness | Warning | DiagnosticAnalyzerAttributeAnalyzer
RS1005 | MicrosoftCodeAnalysisCorrectness | Warning | ReportDiagnosticAnalyzer
RS1006 | MicrosoftCodeAnalysisCorrectness | Warning | RegisterActionAnalyzer
RS1007 | MicrosoftCodeAnalysisLocalization | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1008 | MicrosoftCodeAnalysisPerformance | Warning | DiagnosticAnalyzerFieldsAnalyzer
RS1009 | MicrosoftCodeAnalysisCompatibility | Error | InternalImplementationOnlyAnalyzer
RS1010 | Correctness | Warning | FixerWithFixAllAnalyzer
RS1011 | Correctness | Warning | FixerWithFixAllAnalyzer
RS1012 | MicrosoftCodeAnalysisPerformance | Warning | RegisterActionAnalyzer
RS1013 | MicrosoftCodeAnalysisPerformance | Warning | RegisterActionAnalyzer
RS1015 | MicrosoftCodeAnalysisDocumentation | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1016 | Correctness | Warning | FixerWithFixAllAnalyzer
RS1017 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1018 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1019 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1020 | MicrosoftCodeAnalysisDesign | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1021 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1022 | MicrosoftCodeAnalysisCorrectness | Warning | DiagnosticAnalyzerApiUsageAnalyzer
RS1023 | Library | Warning | UpgradeMSBuildWorkspaceAnalyzer

## Release 3.0.0

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1024 | MicrosoftCodeAnalysisCorrectness | Warning | CompareSymbolsCorrectlyAnalyzer
RS1025 | MicrosoftCodeAnalysisCorrectness | Warning | ConfigureGeneratedCodeAnalysisAnalyzer
RS1026 | MicrosoftCodeAnalysisCorrectness | Warning | EnableConcurrentExecutionAnalyzer
RS1027 | MicrosoftCodeAnalysisCorrectness | Warning | ClassIsNotDiagnosticAnalyzer
RS1028 | MicrosoftCodeAnalysisDocumentation | Disabled | DiagnosticDescriptorCreationAnalyzer
RS1029 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1030 | MicrosoftCodeAnalysisCorrectness | Warning | DoNotUseCompilationGetSemanticModelAnalyzer
RS2000 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2001 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2002 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2003 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2004 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2005 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2006 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2007 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)
RS2008 | MicrosoftCodeAnalysisReleaseTracking | Warning | DiagnosticDescriptorCreationAnalyzer, [Documentation](https://github.com/dotnet/roslyn-analyzers/blob/main/src/Microsoft.CodeAnalysis.Analyzers/ReleaseTrackingAnalyzers.Help.md)

## Release 3.3.0

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1031 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1032 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
RS1033 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer

## Release 3.3.3

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1034 | MicrosoftCodeAnalysisPerformance | Warning | PreferIsKindAnalyzer

## Release 3.3.4

### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|-------
RS1014 | MicrosoftCodeAnalysisCorrectness | Warning | ImmutableObjectMethodAnalyzer
RS1035 | MicrosoftCodeAnalysisCorrectness | Error | SymbolIsBannedInAnalyzersAnalyzer
RS1036 | MicrosoftCodeAnalysisCorrectness | Warning | SymbolIsBannedInAnalyzersAnalyzer
RS1037 | MicrosoftCodeAnalysisDesign | Warning | DiagnosticDescriptorCreationAnalyzer
